pub enum TableError {
WrongColumnCount(usize, usize),
WrongKeyColumnCount(usize, usize),
TransportError(Error),
}Expand description
A failed Table operation.
Variants
WrongColumnCount(usize, usize)
The wrong number of columns was given when inserting a row.
WrongKeyColumnCount(usize, usize)
The wrong number of key columns was given when modifying a row.
TransportError(Error)
The underlying connection to Noria produced an error.